==> tecfy_core_package-0.0.4.tar.gz: lib/services/database.service.dart <==
part of tecfy_core_client_package;



class DatabaseService {
  static Database db;
  static String pathString;
  static String _dbPath = 'main.db';
  static LocalStorage storage;
  
  static init() async {
    try {
      if(kIsWeb ?? false){
        storage = new LocalStorage('localDB.json');
      }else
      if((Platform.isAndroid || Platform.isIOS)){
        pathString = (await path.getApplicationDocumentsDirectory()).path + '/';
        //await deleteDatabase(_dbPath);
        db = await openDatabase(_dbPath,version: 2, onCreate: (db,v )=> _createDatabase(db,0,v),onUpgrade: _createDatabase,onDowngrade: _createDatabase);
        print('db has been inited successfully !!!!!!!!!!!!!');
      }else{
        pathString = "c:\\data\\";
      }
    }catch(err){
      // cannot get path means it's windows
      pathString = "c:\\data\\";
      print('xxxxxxxxxxxxxx  error inital database xxxxxxxxxxxx');
      print(err);
    }
  }

  static Future<void> _createDatabase(Database _db,int _fromVerison, int _toVersion)async{
    try{
      var fmVersion =0;
      var appVersion =0;

        if(_fromVerison <=1)
        await _db.execute('CREATE TABLE Message (uid TEXT PRIMARY KEY, fromUserId INTEGER,toUserId INTEGER,body TEXT, fromName TEXT,toName TEXT, time INTEGER,imSender INTEGER)');

        await TecfyCoreApp.updateSqlLiteDb(_db,_fromVerison,_toVersion);
    }catch(err){
      print(err);
    }
  }

  static Future<void> deleteDatabaseFile()async{
    try{
      await deleteDatabase(_dbPath);
    }catch(err){
      print('xxxxxxxxxxxxxx  error deleting database xxxxxxxxxxxx');
      print(err);
    }
  }

  static Future<OperationResult> insert(String table,Map<String,dynamic> data)async{
    if(db == null || !db.isOpen)return OperationResult(success: false);
      var res = await db.insert(table, data);
      return OperationResult(success: res > 0);
  }

  static Future<OperationResult> writeCollection(String entity, List<dynamic> data)async{
    
    try{
      if(kIsWeb){
        storage.setItem(entity, data);
      }else
      {
        var file = File("$pathString$entity.json");
        await file.writeAsString(json.encode(data));
      }
      return OperationResult(success: true);
    }catch(err){
      // print('XXXXXXXXXXXXXXXXX  write local collection ($entity) $err');
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<List<dynamic>>> readCollection(String entity)async{
    
    try{
      // print('--------------- read local collection ($entity)------------------');
      List<dynamic> data;
      if(kIsWeb){
        data = storage.getItem(entity);
      }else{
        var file = File("$pathString$entity.json");
        data = json.decode(await file.readAsString());
      }
      if(data == null) return OperationResult(success: false);
      return OperationResult(success: true, data: data);
    }catch(err){
      //print('XXXXXXXXXXXXXXXXX  read local collection ($entity) ("$pathString$entity.json") $err');
      return OperationResult(success: false, message: err.toString());
    }
  }


}

==> tecfy_core_package-0.1.8.tar.gz: lib/services/database.service.dart <==
part of tecfy_core_client_package;



class DatabaseService {
  static Database db;
  static String pathString;
  static String _dbPath = 'main.db';
  static LocalStorage storage;
  static bool isInit =false;
  static init() async {
    try {
      if(kIsWeb ?? false){
        storage = new LocalStorage('localDB.json');
      }else
      if((Platform.isAndroid || Platform.isIOS)){
        pathString = (await path.getApplicationDocumentsDirectory()).path + '/';
        //await deleteDatabase(_dbPath);
        db = await openDatabase(_dbPath,version: 2, onCreate: (db,v )=> _createDatabase(db,0,v),onUpgrade: _createDatabase,onDowngrade: _createDatabase);
        print('db has been inited successfully !!!!!!!!!!!!!');
      }else{
        pathString = "c:\\data\\";
      }
    }catch(err){
      // cannot get path means it's windows
      pathString = "c:\\data\\";
      print('xxxxxxxxxxxxxx  error inital database xxxxxxxxxxxx');
      print(err);
    }
    isInit =true;
  }

  static Future<void> _createDatabase(Database _db,int _fromVerison, int _toVersion)async{
    try{
      // var fmVersion =0;
      // var appVersion =0;

        if(_fromVerison <=1)
        await _db.execute('CREATE TABLE Message (uid TEXT PRIMARY KEY, fromUserId INTEGER,toUserId INTEGER,body TEXT, fromName TEXT,toName TEXT, time INTEGER,imSender INTEGER)');

        await TecfyCoreApp.updateSqlLiteDb(_db,_fromVerison,_toVersion);
    }catch(err){
      print(err);
    }
  }

  static Future<void> deleteDatabaseFile()async{
    try{
      await deleteDatabase(_dbPath);
    }catch(err){
      print('xxxxxxxxxxxxxx  error deleting database xxxxxxxxxxxx');
      print(err);
    }
  }

  static Future<OperationResult> insert(String table,Map<String,dynamic> data)async{
    if(db == null || !db.isOpen)return OperationResult(success: false);
      var res = await db.insert(table, data);
      return OperationResult(success: res > 0);
  }

  static Future<OperationResult> writeCollection(String entity, List<dynamic> data)async{
    
    try{
      if(kIsWeb){
        storage.setItem(entity, data);
      }else
      {
        var file = File("$pathString$entity.json");
        await file.writeAsString(json.encode(data));
      }
      return OperationResult(success: true);
    }catch(err){
      print('XXXXXXXXXXXXXXXXX  write local collection ($entity) $err');
      return OperationResult(success: false, message: err.toString());
    }
  }

  static Future<OperationResult<List<dynamic>>> readCollection(String entity)async{
    
    try{
      while(!isInit)
        await Future.delayed(Duration(milliseconds: 100));
      
      // print('--------------- read local collection ($entity)------------------');
      List<dynamic> data;
      if(kIsWeb){
        data = storage.getItem(entity);
      }else{
        var file = File("$pathString$entity.json");
        data = json.decode(await file.readAsString());
      }
      if(data == null) return OperationResult(success: false);
      return OperationResult(success: true, data: data);
    }catch(err){
      //print('XXXXXXXXXXXXXXXXX  read local collection ($entity) ("$pathString$entity.json") $err');
      return OperationResult(success: false, message: err.toString());
    }
  }


}
